/*******************************************************************/
/*

Demo-Software for smart cameras from Vision Components
------------------------------------------------------

Program: Peter Neuhaus,  VC


Program Description:
--------------------

This program demonstrates the use of the encoder interface.
4 images are taken during one turn at counter 0, 256, 512 and 768
The printout shows the actual counter value, the currently set reload value
and the current MSEC value.

In this program the counter resets every revolution at the "N" (Zero or 0+) pulse,
calling the macro "ENC_WAIT_N_TRIG();" at the beginning of the program.

*/
/*******************************************************************/

#include <vcrt.h>
#include <vclib.h>
#include <macros.h>
#include <sysvar.h>
#include <flib.h>
#include <licence.h>	// internal VC header including init_licence() functions, see "Getting Started VC", section 4

/*******************************************************************/

void main(void)
{ 

I32 Run = 1, TrackNr=0; 
U32 Reload = 256; 
char c; 

INIT_LICENCE();								// internal VC macro initialising licences


shutter(10); 								// setting the shutter to 10 microseconds


print("\nEncoder Interface Test, press <ESC> to abort\n\n"); 

TRIGINP_NEG() ; 							// clockwise rotation 
TRIGOUT_EXP(); 
TRIGOUT_POS(); 


tpict(); 									// take image to end live mode 

INTERFACE_MODE(ENCODER);					// Encoder mode (RS232 disabled) 
ENC_DISABLE_CNT(); 							// disable counter 
//ENC_WAIT_N();		 						// wait one time for next 0+ pulse 
ENC_WAIT_N_TRIG(); 							// wait every time for next 0+ pulse 
ENC_ENABLE_CNT(); 							// enable inputs 
ENC_WRITE_CNT(0); 							// set Counter value 
ENC_WRITE_RELOAD(Reload); 					// set Reload value 

setPLC0(); 									// this starts the motor - clockwise rotation, when looking towards the motor 


while(Run) 									// Image acquisition loop  see trigin.c in Programming Tutorial Basics 
	{

 	TrackNr= capture_request(getvar(EXPCNT), getvar(GAIN),(int*)ScrGetCaptPage,1); // calling image acquisition request

	while(TrackNr != getvar(IMGREADY)); 	// wait for image completion (only works if cycle time > exp. + transfer time) 
	{
		ENC_WRITE_RELOAD(Reload); 			// Writing the Reload value for the image after the next 
		Reload = Reload +256; 				// Incrementing the Reload value 
		if(Reload>790) Reload =0;
 		
 		if(kbhit()) 						// check for keyboard input 
 		{ 
 		c=rs232rcv(); 

 		if(c==0x1B) 						// check for "ESC" 
 			{ 
 			while(cancel_capture_rq());
	 		Run = 0; 						// deleting last capture request 
	 		} 

	 	} 
	 	
	 	printf("%08d, %d, %d\n",ENC_READ_CNT(), Reload, getvar(MSEC)); 
 		time_delay(1); 						// waiting time to slow printing 
 	} 
 } 
 
 INTERFACE_MODE(SERIAL);					// Serial mode (RS232 enabled) 
 
 vmode(0); // switching camera back to live mode 
 
 resPLC0(); 								// turn off the motor
 

 }
 /*******************************************************************/


